//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Files/DatafilesQModel.h
//! @brief     Defines class DatafilesQModel.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_FILES_DATAFILESQMODEL_H
#define BORNAGAIN_GUI_MODEL_FILES_DATAFILESQMODEL_H

#include <QAbstractItemModel>

class DatafileItem;
class DatafilesSet;

//! Tree representation of DatafilesSet, for use in DatafilesSelector.

class DatafilesQModel : public QAbstractItemModel {
    Q_OBJECT
public:
    explicit DatafilesQModel(QObject* parent, DatafilesSet* model);

    bool setData(const QModelIndex& index, const QVariant& value, int role) override;
    void injectDatafileItem(DatafileItem* item);
    void removeDatafileItem(DatafileItem* item);

    QModelIndex index(int row, int column, const QModelIndex& parent = {}) const override;
    QModelIndex parent(const QModelIndex& index) const override;
    int columnCount(const QModelIndex& parent = {}) const override;
    int rowCount(const QModelIndex& parent = {}) const override;
    QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
    Qt::ItemFlags flags(const QModelIndex& index) const override;

    DatafileItem* itemForIndex(const QModelIndex& index) const;
    QModelIndex indexForItem(DatafileItem* item) const;
    DatafileItem* topMostItem() const; //!< The topmost visible item. Can be null.
    bool isHeadline(const QModelIndex& index) const;

private:
    QModelIndex indexOfHeadline() const;

    DatafilesSet* const m_model;
    QVector<DatafileItem*> m_items; //< Items borrowed from model. Never delete the ptrs!
};

#endif // BORNAGAIN_GUI_MODEL_FILES_DATAFILESQMODEL_H
