//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Files/DatafilesSet.h
//! @brief     Defines class DatafilesSet.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_FILES_DATAFILESSET_H
#define BORNAGAIN_GUI_MODEL_FILES_DATAFILESSET_H

#include "Base/Types/OwningVector.h"
#include "GUI/Model/Files/DatafilesCleaner.h"
#include <QObject>
#include <QXmlStreamWriter>

class DataItem;
class DatafileItem;
class MessageService;

//! The DatafilesSet class is a model to store all imported DatafileItem's.
class DatafilesSet : public QObject {
    Q_OBJECT
public:
    explicit DatafilesSet();
    ~DatafilesSet();

    void insertDatafileItem(DatafileItem* dfi);
    void removeDatafileItem(DatafileItem* dfi);
    void clear();
    void readFrom(QXmlStreamReader* r);
    void readDatafiles(const QString& projectDir, MessageService* messageService);
    void setCurrentIndex(int index) { m_current_index = index; }

    size_t size() const { return m_dfile_items.size(); }
    const OwningVector<DatafileItem>& dfileItems2() const { return m_dfile_items; }
    QVector<DatafileItem*> dfileItems() const;
    QStringList realItemNames() const;
    int currentIndex() const { return m_current_index; }
    void writeTo(QXmlStreamWriter* w) const;
    void writeDatafiles(const QString& projectDir) const;

private:
    QVector<DataItem*> dataItems() const;

    mutable DatafilesCleaner dataFilesCleaner;
    OwningVector<DatafileItem> m_dfile_items;
    int m_current_index = -1;
};

#endif // BORNAGAIN_GUI_MODEL_FILES_DATAFILESSET_H
